@@ -405,8 +405,8 @@
         plot(xlim, opt$ylim, xlab = opt$xlab, ylab = opt$ylab, type = "n")
         polygon(c(eval.points, rev(eval.points)), c(upper, rev(lower)),
             col = "cyan", border = 0)
-        lines(eval.points, estimate[1, ], lty = opt$lty[1], col = opt$col[1])
-        lines(eval.points, estimate[2, ], lty = opt$lty[2], col = opt$col[2])
+        lines(eval.points, estimate[1, ], lty = opt$lty[1], col = opt$col[1], lwd = opt$lwd)
+        lines(eval.points, estimate[2, ], lty = opt$lty[2], col = opt$col[2], lwd = opt$lwd)
         est <- list(p = p, estimate = estimate, eval.points = eval.points, 
                     upper = upper, lower = lower, h = h)
     }
