@@ -1,5 +1,5 @@
 ## Note: R CMD check may run these scripts from an installed package
-scripts <- list.files(system.file("scripts", package = "sm"), ".*\.q$")
+scripts <- list.files(system.file("scripts", package = "sm"), ".*\\.q$")
 ## these are interactive
 omit2 <- match(c("bissell3.q", "dogs.q"), scripts)
 scripts <- scripts[-omit2]
